<?php
// $Id: settings.inc,v 1.1.2.4 2010/07/05 08:00:41 pobster Exp $

/**
 * @file
 * Settings file for Gamertags module.
 */

/**
 * Administrative setting callback.
 */
function gamertags_settings() {
  drupal_add_js(drupal_get_path('module', 'gamertags') .'/misc/settings.js');
  $form['collect'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gamertag Usage'),
    '#description' => t('Collect and Display:'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['collect']['gamertags_collect_xbox'] = array(
    '#type' => 'checkbox',
    '#title' => t("Xbox Gamertags"),
    '#default_value' => variable_get('gamertags_collect_xbox', TRUE),
  );
  $form['collect']['gamertags_collect_psn'] = array(
    '#type' => 'checkbox',
    '#title' => t("Playstation Gamertags"),
    '#default_value' => variable_get('gamertags_collect_psn', TRUE),
  );
  $form['collect']['gamertags_collect_wii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Wii Friend Codes"),
    '#default_value' => variable_get('gamertags_collect_wii', TRUE),
  );
  $form['collect']['gamertags_collect_steam'] = array(
    '#type' => 'checkbox',
    '#title' => t("Steam Gamertags"),
    '#default_value' => variable_get('gamertags_collect_steam', TRUE),
  );
  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Gamertag Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['settings']['gamertags_on_registration'] = array(
    '#type' => 'checkbox',
    '#title' => t("Ask for Gamertags on registration screen"),
    '#description' => t("Check this if you want users to be able to input their Gamertags on the user registration page as well as from their user account pages after they've registered."),
    '#default_value' => variable_get('gamertags_on_registration', TRUE),
  );
  $form['settings']['gamertags_debunk_ms'] = array(
    '#type' => 'checkbox',
    '#title' => t("Don't use Xbox.com for Xbox gamercard"),
    '#description' => t("If you use Xbox.com then you have to be happy with Microsofts 'solution' of having your Gamertags inside iframes.  Checking this box will use Gamertags from MyGamercard.net instead of official (but iframed) ones."),
    '#default_value' => variable_get('gamertags_debunk_ms', FALSE),
  );
  $form['settings']['gamertags_use_mapwii'] = array(
    '#type' => 'checkbox',
    '#title' => t("Use mapwii.com for Wii Friend Codes"),
    '#description' => t("Check this box to allow users wii friend codes to link through to the mapwii.com friend code repository."),
    '#default_value' => variable_get('gamertags_use_mapwii', FALSE),
  );
  $form['urls'] = array(
    '#type' => 'fieldset',
    '#title' => t('URL Settings'),
    '#description' => t("You should never need to change these settings but if you do, note that the URL needs to be fully formed and it <strong>must</strong> contain <strong>ONE</strong> string replacement symbol '<strong>%s</strong>' which will be where the console username is swapped in.  See the defaults for examples of usage."),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['urls']['message'] = array(
    '#type' => 'markup',
    '#value' => _gamertags_test_any() ? ' ' : t('No Gamertags are set to be displayed.'), // The ' ' is a placeholder so the message div actually gets displayed. Maybe in future I'll just pass this form to a theme function as this looks a little messy?
    '#prefix' => _gamertags_test_any() ? '<div id="gamertags_message">' : '<div class="error" id="gamertags_message">',
    '#suffix' => '</div>',
  );
  $form['urls']['gamertags_xbox_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Xbox (Microsoft) URL'),
    '#default_value' => variable_get('gamertags_xbox_url', "http://gamercard.xbox.com/%s.card"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_mygamercard_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Xbox (MyGamerCard) URL'),
    '#default_value' => variable_get('gamertags_mygamercard_url', "http://card.mygamercard.net/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_psn_eu_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (European) URL'),
    '#default_value' => variable_get('gamertags_psn_eu_url', "http://mypsn.eu.playstation.com/psn/profile/%s.jpg"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_psn_us_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Playstation Network (American) URL'),
    '#default_value' => variable_get('gamertags_psn_us_url', "http://fp.profiles.us.playstation.com/playstation/psn/pid/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_wii_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Wii URL'),
    '#default_value' => variable_get('gamertags_wii_url', "http://mapwii.com/wii-number/member.cfm?wii_number=%s"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['urls']['gamertags_steam_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Steam Card URL'),
    '#default_value' => variable_get('gamertags_steam_url', "http://steamcard.com/do/modern/%s.png"),
    '#required' => TRUE,
    '#size' => 70,
  );
  $form['#validate'][] = 'gamertags_settings_validate';
  return system_settings_form($form);
} // gamertags_settings

/**
 * Form validation for checking URLs contain at least one string replacement symbol.
 */
function gamertags_settings_validate($form, &$form_state) {
  foreach (element_children($form['urls']) as $key) {
    if ($key == 'message') { // Again with the maybe I'll just pass the rendering of this form to a theme function at some point...
      continue;
    }
    if (!preg_match("/%s/", $form_state['values'][$key])) {
      dsm($key);
      form_set_error($key, t("Error, URL must contain a string replacement symbol i.e. '%s'"));
    }
    elseif (preg_match_all("/(%s+)/", $form_state['values'][$key], $matches) && count($matches[0]) != 1) {
      form_set_error($key, t("Error, URL must contain only ONE string replacement symbol i.e. '%s'"));
    }
  }
} // gamertags_settings__validate